##  Impact Type Classification Rules
The classification of Impact Types follows these rules:
### Classification of Application Impacts
Changes to lifecycle
Implied/Custom Impact | Impact Type
---|---
Application set to active | Introduction
Application set to phase out | Discontinuation
Application set to end of life | Decommissioning


Changes to related Organization
Implied/Custom Impact | Impact Type
---|---
Organization relation added to Application | Rollout
Organization relation removed from Application | Withdrawal


Changes to other related objects
Implied/Custom Impact | Impact Type
---|---
Business Capability relation added / removed | Scope Change
IT Component relation added / removed | Technical Change
Interface relation added / removed | Interface Change


### Classification of Interface Impacts
Changes to lifecycle
Implied/Custom Impact | Impact Type
---|---
Interface set to active | Introduction
Interface set to phase out | Discontinuation
Interface set to end of life | Decommissioning


Changes to related Organizations (non-standard configuration)
Implied/Custom Impact | Impact Type
---|---
Organization relation added to Interface | Rollout
Organization relation removed from Interface | Withdrawal


Changes to other related objects
Implied/Custom Impact | Impact Type
---|---
Data Object relation added / removed | Scope Change
IT Component relation added / removed | Technical Change


